/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.bcoca;

/**
 * The attributes specific to a Code39 barcode
 */
import org.apache.fop.render.afp.modca.AFPConstants;

public class Code39 extends LinearSymbologies {

	/**
	 * The checksum flag
	 */
	private boolean checkDigitEnabled = true;

	/**
	 * @see BarcodeSymbologies#getBarCodeModifier()
	 */
	public byte getBarCodeModifier() {

			if (!checkDigitEnabled) {
				// Do not generate the checksum
				return 0x01;
			} else {
				// Default is to generate the checksum
				return 0x02;
			}
			
	}

	/**
	 * @see BarcodeSymbologies#getBarCodeType()
	 */
	public byte getBarCodeType() {
		// The code to indicate Code39
		return 0x01;
	}
	
	/**
	 * @see BarcodeSymbologies#getDataEncoding()
	 */
	public String getDataEncoding() {
		return AFPConstants.EBCIDIC_ENCODING;
	}
	
	/**
	 * @see BarcodeSymbologies#getSpecialFunctions()
	 */
	public byte[] getSpecialFunctions() {
		
		return new byte[] {};
			
	}

	/**
	 * @return true if the check digit should be generated
	 */
	public boolean isCheckDigitEnabled() {
		return checkDigitEnabled;
	}

	/**
	 * Setter to enable/disable the check digit generation
	 * @param enabled
	 */
	public void setCheckDigitEnabled(boolean enabled) {
		this.checkDigitEnabled = enabled;
	}

}
