/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.bcoca;

/**
 * Linear symbologies can be either width-modulated or height-modulated. The latter is mostly used 
 * in postal applications. Based on the character set, the symbologies can be further divided into 
 * two categories of numeric or alpha-numeric.
 */
public abstract class LinearSymbologies extends BarcodeSymbologies {
	
	/**
	 * Flag to indicate if the HRI should be preseneted
	 */
	private boolean humanReadablePresented = true;
	
	/**
	 * Flags to indicate if the position of the HRI 
	 */
	private boolean hriPositionBelow = false;
	private boolean hriPositionAbove = false;
	
	/**
	 * Flag to indicate if the asterisk is presented
	 */
	private boolean asteriskPresented = false;

	/**
	 * @return true if the human readable text should be at the below
	 */
	public boolean isHRIPositionBelow() {
		return hriPositionBelow;
	}
	
	/**
	 * @return true if the human readable text should be at the above
	 */
	public boolean isHRIPositionAbove() {
		return hriPositionAbove;
	}

	/**
	 * Set to true to position above, false will position at the bottom.
	 * @param above
	 */
	public void setHRIPositionAbove(boolean above) {
		hriPositionAbove = above;
		hriPositionBelow = !above;
	}
	
	/**
	 * Set to true to position below, false will position at the top.
	 * @param below
	 */
	public void setHRIPositionBelow(boolean below) {
		hriPositionBelow = below;
		hriPositionAbove = !below;
	}

	/**
	 * @return true if the human readable text should be presented
	 */
	public boolean isHRIPresented() {
		return humanReadablePresented;
	}

	/**
	 * Setter for the human readable presented flag
	 * @param humanReadablePresented
	 */
	public void setHRIPresented(boolean humanReadablePresented) {
		this.humanReadablePresented = humanReadablePresented;
	}

	/**
	 * @return true if the asterisk should be presented
	 */
	public boolean isAsteriskPresented() {
		return asteriskPresented;
	}

	/**
	 * Setter to indicate that the asterisk should be presented
	 * @param asteriskPresented
	 */
	public void setAsteriskPresented(boolean asteriskPresented) {
		this.asteriskPresented = asteriskPresented;
	}

}
