/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.bcoca;

import org.apache.fop.render.afp.modca.AFPConstants;
import org.apache.fop.render.afp.tools.BinaryUtils;

/**
 * The attributes specific to a PDF417 barcode
 */

public class PDF417 extends StackedSymbologies {

	/**
	 * Flag to indicate if barcode is truncated
	 */
	private boolean truncated = false;

	/**
	 * The error correction level
	 */
	private int errorCorrection = 4;

	/**
	 * @see BarcodeSymbologies#getBarCodeModifier()
	 */
	public byte getBarCodeModifier() {

		if (truncated) {
			return 0x01;
		} else {
			return 0x00;
		}

	}

	/**
	 * @see BarcodeSymbologies#getBarCodeType()
	 */
	public byte getBarCodeType() {
		// The code to indicate PDF417
		return 0x1E;
	}

	/**
	 * @see BarcodeSymbologies#getDataEncoding())
	 */
	public String getDataEncoding() {
		return AFPConstants.ASCII_ENCODING;
	}

	/**
	 * @see BarcodeSymbologies#getBarCodeModifier()
	 */
	public byte[] getSpecialFunctions() {

		byte[] data = new byte[] { 0x00, BinaryUtils.convert(getColumns())[0],
				(byte) 0xFF, BinaryUtils.convert(errorCorrection)[0], 0x00,
				0x00, };

		return data;

	}

	/**
	 * @return the error correction level
	 */
	public int getErrorCorrection() {
		return errorCorrection;
	}

	/**
	 * Settter for the error correction level
	 *
	 * @param errorCorrection
	 */
	public void setErrorCorrection(int errorCorrection) {
		if (errorCorrection < 0 || errorCorrection > 8) {
			throw new IllegalArgumentException("Error correction level of "
					+ errorCorrection
					+ " is invalid, valid ranges are between 0 and 8.");
		}
		this.errorCorrection = errorCorrection;
	}

	/**
	 * @return true if the barcode symbol should be truncated
	 */
	public boolean isTruncated() {
		return truncated;
	}

	/**
	 * Setter for the truncated flag
	 * 
	 * @param truncated
	 */
	public void setTruncated(boolean truncated) {
		this.truncated = truncated;
	}

	/**
	 * @see BarcodeSymbologies#isHumanReadableSupported()
	 */
	public boolean isHumanReadableSupported() {
		return false;
	}

}
