/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.bcoca;

/**
 * Two-dimensional stacked symbologies allow large amounts of information to be encoded 
 * by effectively stacking short one-dimensional symbols in a row/column arrangement. 
 * This reduces the amount of space that is typically consumed by conventional linear 
 * bar code symbols and allows for a large variety of rectangular bar code shapes.
 */
public abstract class StackedSymbologies extends BarcodeSymbologies {
	
	/**
	 * the element height (i.e. the height of a row)
	 */
	private int elementHeight;
	
	/**
	 * the height multiplier or number of rows
	 */
	private int heightMultiplier = 0;
	
	/**
	 * The number of columns in the barccode
	 */
	private int columns = 3;
	
	/**
	 * @return the height of the element or row
	 */
	public int getElementHeight() {
		return elementHeight;
	}

	/**
	 * Setter for the element height
	 * @param units
	 * @param uom
	 */
	public void setElementHeight(double units, String uom) {
		elementHeight = units2afp(units, uom);
	}
	
	/**
	 * @return the height multiplier (or number of rows)
	 */
	public int getHeightMultiplier() {
		return heightMultiplier;
	}

	/**
	 * Setter for the height multiplier, also know as the number of rows.
	 * @param multiplier
	 */
	public void setHeightMultiplier(int multiplier) {
		heightMultiplier = multiplier;
	}
	
	/**
	 * @return the number of columns
	 */
	public int getColumns() {
		return columns;
	}

	/**
	 * Setter for the number of columns
	 * @param columns
	 */
	public void setColumns(int columns) {
		this.columns = columns;
	}
	

}
