/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.modca;

import org.apache.fop.render.afp.bcoca.BarcodeSymbologies;

/**
 * A Barcode Object Environment Group (OEG) may be associated with an object and
 * is contained within the object's begin-end envelope.
 * 
 * The object environment group defines the object's origin and orientation on
 * the page, and can contain font and color attribute table information. The
 * scope of an object environment group is the scope of its containing object.
 * 
 * An application that creates a data-stream document may omit some of the
 * parameters normally contained in the object environment group, or it may
 * specify that one or more default values are to be used.
 */
public final class BarcodeObjectEnvironmentGroup extends ObjectEnvironmentGroup {

	/**
	 * Default name for the object environment group
	 */
	protected static final String DEFAULT_NAME = "BOEG0001";
	
	/**
	 * the barcode attributes
	 */
	private BarcodeSymbologies _bcocaObject;

	/**
	 * Constructor for the BarcodeObjectEnvironmentGroup
	 * 
	 * @param bcoca
	 *            the barcode attributes
	 */
	public BarcodeObjectEnvironmentGroup(BarcodeSymbologies bcoca) {

		this(DEFAULT_NAME, bcoca);

	}

	/**
	 * Constructor for the BarcodeObjectEnvironmentGroup, this takes a name
	 * parameter which must be 8 characters long.
	 * 
	 * @param name
	 *            the barcode object environment group name
	 * @param bcoca
	 *            the barcode attributes
	 */
	public BarcodeObjectEnvironmentGroup(String name, BarcodeSymbologies bcoca) {

		super(name);
		_bcocaObject = bcoca;
		_dataDescriptor = new BarcodeDataDescriptor(_bcocaObject);
		if (_bcocaObject.getMpts2unitsFactor() == 50) {
			_unitOfMeasure = 14400;
		} else if (_bcocaObject.getMpts2unitsFactor() == 300) {
			_unitOfMeasure = 2400;
		}

	}

	/**
	 * @see ObjectEnvironmentGroup#setObjectArea(int, int, int, int, int)
	 */
	public void setObjectArea(int x, int y, int rotation) {
		super.setObjectArea(x, y, _bcocaObject.getWidth(), _bcocaObject.getHeight(), rotation);
	}

}