/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: $ */

package org.apache.fop.render.afp.modca;


/**
 * An Image Object Environment Group (OEG) may be associated with an object and is contained
 * within the object's begin-end envelope.
 * 
 * The object environment group defines the object's origin and orientation on the page,
 * and can contain font and color attribute table information. The scope of an object
 * environment group is the scope of its containing object.
 *
 * An application that creates a data-stream document may omit some of the parameters
 * normally contained in the object environment group, or it may specify that one or
 * more default values are to be used.
 */
public final class ImageObjectEnvironmentGroup extends ObjectEnvironmentGroup {

	 /**
     * Default name for the object environment group
     */
    protected static final String DEFAULT_NAME = "IOEG0001";
    
    /**
     * Default constructor for the ImageObjectEnvironmentGroup.
     */
    public ImageObjectEnvironmentGroup() {

        this(DEFAULT_NAME);

    }

    /**
     * Constructor for the ImageObjectEnvironmentGroup, this takes a
     * name parameter which must be 8 characters long.
     * @param name the object environment group name
     */
    public ImageObjectEnvironmentGroup(String name) {

        super(name);

    }

    /**
     * Set the dimensions of the image.
     * @param xresol the x resolution of the image
     * @param yresol the y resolution of the image
     * @param width the image width
     * @param height the image height
     */
    public void setImageData(int xresol, int yresol, int width, int height) {
        _dataDescriptor = new ImageDataDescriptor(xresol, yresol,  width, height);
    }

}